# `almanack` Package API

## Metrics

### Data

```{eval-rst}
.. automodule:: almanack.metrics.data
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

## Garden Lattice

### Understanding

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.understanding
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

### Connectedness

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.connectedness
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```

### Practicality

```{eval-rst}
.. automodule:: almanack.metrics.garden_lattice.practicality
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
```
